Create a list with all the text elements of the selectivity sheet in the selected language
create_translate_dict(
path = system.file("template", "translation.csv", package = "inser"),
language = c("EN", "FR"),
encoding = "UTF-8",
sep = ";"
)list. A list of translated text, with names referring to their location in the sheet
# create the EN translator
lg <- create_translate_dict(language = "EN")
#> Using the EN version of the selectivity template
# call main title by its ID
cat(lg[["0_main_title"]])
#> Selectivity sheet - InseR
# create the FR translator
lg <- create_translate_dict(language = "FR")
#> Using the FR version of the selectivity template
# call main title by its ID
cat(lg[["0_main_title"]])
#> Fiche de sélectivité - InseR